@@ -18,11 +18,6 @@ require_once(__DIR__ . '/../../libs/api_auth.php');
 require_once(__DIR__ . '/../../libs/usermgmt.php');
 
 try {
-    // Debug incoming request for user management API
-    error_log("Users API Request - Method: " . $_SERVER['REQUEST_METHOD']);
-    error_log("Users API Request - Headers: " . json_encode(getallheaders()));
-    error_log("Users API Request - GET params: " . json_encode($_GET));
-    
     // Authenticate and check permissions
     $authData = api_authenticate('user_management');
     
@@ -207,6 +202,27 @@ function createUser($userMgmt, $input, $authData) {
             }
         }
         
+        // Create domain if provided
+        $domain = $input['domain'] ?? '';
+        if (!empty($domain)) {
+            try {
+                $domainResult = createUserDomain($input['username'], $domain);
+                if ($domainResult['success']) {
+                    $userData['domain_created'] = $domain;
+                    $userData['domain_id'] = $domainResult['domain_id'];
+                    if (isset($domainResult['warnings']) && !empty($domainResult['warnings'])) {
+                        $userData['domain_warnings'] = $domainResult['warnings'];
+                    }
+                } else {
+                    $userData['domain_error'] = $domainResult['error'];
+                }
+            } catch (Exception $e) {
+                error_log("Failed to create domain for user {$input['username']}: " . $e->getMessage());
+                // Don't fail the user creation, just log the domain creation failure
+                $userData['domain_error'] = 'Domain creation failed: ' . $e->getMessage();
+            }
+        }
+        
         api_response(true, $userData, 'User created successfully');
     } else {
         api_response(false, null, $result['msg'], 400);
@@ -446,4 +462,107 @@ function getUserUsage($username) {
         return null;
     }
 }
+
+/**
+ * Create a domain for a user (following the same process as domains.php)
+ */
+function createUserDomain($username, $domain_name) {
+    try {
+        require_once(__DIR__ . '/../../libs/mysqlmgmt.php');
+        require_once(__DIR__ . '/../../libs/pdns-integration.php');
+        require_once(__DIR__ . '/../../libs/emailmgmt.php');
+        
+        $MySQLMgmt = new mysqlmgmt();
+        $db = $MySQLMgmt->getMySQLConnection();
+        
+        if (!$db) {
+            return ['success' => false, 'error' => 'Database connection failed'];
+        }
+        
+        $domain_name = strtolower(trim($domain_name));
+        
+        // Validate domain format
+        if (!filter_var('http://' . $domain_name, FILTER_VALIDATE_URL)) {
+            return ['success' => false, 'error' => 'Invalid domain format'];
+        }
+        
+        // Check if domain already exists in WHP
+        $stmt = $db->prepare("SELECT id FROM whp.domains WHERE domain_name = ?");
+        $stmt->execute([$domain_name]);
+        if ($stmt->fetch()) {
+            return ['success' => false, 'error' => 'Domain already exists in the system'];
+        }
+        
+        // Initialize PowerDNS integration
+        $pdns = new PowerDNSIntegration($db);
+        
+        // Create PowerDNS zone first
+        $zone_result = $pdns->createZoneForDomain($domain_name, $username);
+        if (!$zone_result['success']) {
+            return ['success' => false, 'error' => 'Failed to create DNS zone: ' . $zone_result['error']];
+        }
+        
+        // Insert domain into WHP database
+        $stmt = $db->prepare("
+            INSERT INTO whp.domains (domain_name, username, active) 
+            VALUES (?, ?, 1)
+        ");
+        $stmt->execute([$domain_name, $username]);
+        $domain_id = $db->lastInsertId();
+        
+        $warnings = [];
+        
+        // Initialize Email Management for mail server synchronization
+        try {
+            $EmailMgmt = new emailmgmt();
+            
+            // Add domain to mail server
+            $mail_result = $EmailMgmt->createMailServerDomain($domain_name, [
+                'disabled' => false,
+                'reference_id' => $username
+            ]);
+            
+            if ($mail_result['status'] !== '0') {
+                $warnings[] = 'Mail server sync failed: ' . $mail_result['msg'];
+            } else {
+                // Wait for mail server to process domain creation
+                sleep(3);
+                
+                // Generate DKIM records on mail server with retry logic
+                try {
+                    $dkim_result = $EmailMgmt->createDkimRecordsWithRetry($domain_name, $username, 3, 2);
+                    if ($dkim_result['status'] !== '0') {
+                        $warnings[] = 'DKIM setup failed: ' . $dkim_result['msg'];
+                    } else {
+                        // Add DKIM DNS record to PowerDNS
+                        $dns_result = $EmailMgmt->createDkimDnsRecord($domain_name, null, null, $username);
+                        if ($dns_result['status'] !== '0') {
+                            $warnings[] = 'DKIM DNS record creation failed: ' . $dns_result['msg'];
+                        }
+                    }
+                } catch (Exception $e) {
+                    $warnings[] = 'DKIM setup failed: ' . $e->getMessage();
+                }
+            }
+        } catch (Exception $e) {
+            $warnings[] = 'Email integration failed: ' . $e->getMessage();
+        }
+        
+        $result = [
+            'success' => true,
+            'domain_id' => $domain_id,
+            'domain_name' => $domain_name
+        ];
+        
+        if (!empty($warnings)) {
+            $result['warnings'] = $warnings;
+        }
+        
+        return $result;
+        
+    } catch (Exception $e) {
+        error_log("Error creating user domain: " . $e->getMessage());
+        return ['success' => false, 'error' => $e->getMessage()];
+    }
+}
 ?>
\ No newline at end of file
